@@ -220,7 +220,7 @@ def loop_through_chunks(
                     sc_client,
                     audit,
                     get_started,
-                    all_audits=all_audits
+                    all_audits=all_audits,
                 )
                 export_count += 1
         if "sql" in settings[EXPORT_FORMATS]:
@@ -230,14 +230,7 @@ def loop_through_chunks(
             update_sync_marker_file(modified_at, settings[CONFIG_NAME])
 
 
-def process_audit(
-    logger,
-    settings,
-    sc_client,
-    audit,
-    get_started,
-    all_audits=[]
-):
+def process_audit(logger, settings, sc_client, audit, get_started, all_audits=[]):
     """
     Export audit in the format specified in settings. Formats include PDF, JSON, CSV, MS Word (docx), media, or
     web report link.
