@@ -79,7 +79,9 @@ def sql_setup(logger, settings, action_or_audit):
             table = settings[ACTIONS_TABLE]
         else:
             table = "iauditor_actions_data"
-        Database = set_actions_table(table, actions_merge, Base, user_schema=settings[DB_SCHEMA])
+        Database = set_actions_table(
+            table, actions_merge, Base, user_schema=settings[DB_SCHEMA]
+        )
     else:
         sys.exit()
 
